@@ -85,7 +85,7 @@ def build(path: str):
         if folds:
             fda = Path(
                 os.path.join(
-                    'Archive_' + pth.name, 
+                    ('Archive_' + pth.name), 
                     f'{str(dt.timestamp(dt.now())).replace(".", "_")}'
                 )
             )
@@ -110,18 +110,25 @@ def build(path: str):
                 
 def publish(path: str):
     # Upload to PyPI.
-    
-    if platform.startswith('win'):
-        os.chdir(os.environ['USERPROFILE'])
-    else:
-        os.chdir(os.environ['HOME'])
-    if '.pypirc' in os.listdir():
-        pnam = f'py -m twine upload "{path}"' if platform.startswith('win') else 'python3 -m twine upload "{path}"'.split()
-        with Popen(pnam, stdout = PIPE, bufsize = 1, universal_newlines = True, text = True) as p:
-            for line in p.stdout:
-                print(line, end='')
+    if os.path.exists('.pypirc'):
+        if platform.startswith('win'):
+            os.chdir(os.environ['USERPROFILE'])
+            pnam = f'py -m twine upload "{path}"'
+            with Popen(
+                pnam, stdout = PIPE, bufsize = 1, 
+                universal_newlines = True, text = True
+            ) as p:
+                for line in p.stdout:
+                    print(line, end='')
+        else:
+            #os.chdir(os.environ['HOME'])
+            print(
+                f'\n{61*"-"}\nWrite "python3 -m twine upload dist/*" '
+                f'for uploading to PyPI!\n{61*"-"}\n'
+            )
     else:
         print('Please create token first!')
+   
         
 def main():
     # This will only work in cli.
